Struct ProgressStyle
pub struct ProgressStyle { /* private fields */ }Implementations
impl ProgressStyle
impl ProgressStyle
pub fn default_bar() -> ProgressStyle
pub fn default_bar() -> ProgressStyle
Returns the default progress bar style for bars
pub fn default_spinner() -> ProgressStyle
pub fn default_spinner() -> ProgressStyle
Returns the default progress bar style for spinners
pub fn with_template(template: &str) -> Result<ProgressStyle, TemplateError>
pub fn with_template(template: &str) -> Result<ProgressStyle, TemplateError>
Sets the template string for the progress bar
Review the list of template keys for more information.
pub fn tick_chars(self, s: &str) -> ProgressStyle
pub fn tick_chars(self, s: &str) -> ProgressStyle
Sets the tick character sequence for spinners
Note that the last character is used as the final tick string. At least two characters are required to provide a non-final and final state.
pub fn tick_strings(self, s: &[&str]) -> ProgressStyle
pub fn tick_strings(self, s: &[&str]) -> ProgressStyle
Sets the tick string sequence for spinners
Note that the last string is used as the final tick string. At least two strings are required to provide a non-final and final state.
pub fn progress_chars(self, s: &str) -> ProgressStyle
pub fn progress_chars(self, s: &str) -> ProgressStyle
Sets the progress characters (filled, current, to do)
You can pass more than three for a more detailed display. All passed grapheme clusters need to be of equal width.
pub fn with_key<S>(self, key: &'static str, f: S) -> ProgressStylewhere
S: ProgressTracker + 'static,
pub fn with_key<S>(self, key: &'static str, f: S) -> ProgressStylewhere
S: ProgressTracker + 'static,
Adds a custom key that owns a [ProgressTracker] to the template
pub fn template(self, s: &str) -> Result<ProgressStyle, TemplateError>
pub fn template(self, s: &str) -> Result<ProgressStyle, TemplateError>
Sets the template string for the progress bar
Review the list of template keys for more information.
pub fn get_tick_str(&self, idx: u64) -> &str
pub fn get_tick_str(&self, idx: u64) -> &str
Returns the tick string for a given number
pub fn get_final_tick_str(&self) -> &str
pub fn get_final_tick_str(&self) -> &str
Returns the tick string for the finished state